"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""
# @generated-id: d048447bc7bc

from __future__ import annotations
from enum import Enum


class TransferSchemeType(str, Enum):
    r"""The transfer scheme to be used for the transfer. The transfer scheme determines the processing time and method of the transfer."""

    SEPA_CREDIT_INST = "sepa-credit-inst"
    SEPA_CREDIT = "sepa-credit"
