"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""
# @generated-id: cf97a8e1bc72

from __future__ import annotations
from enum import Enum
from mollie import utils


class VerificationResultEnum(str, Enum, metaclass=utils.OpenEnumMeta):
    r"""The result of the Verification of Payee check."""

    MATCH = "match"
    NO_MATCH = "no-match"
    CLOSE_MATCH = "close-match"
    NOT_AVAILABLE = "not-available"
