"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""
# @generated-id: 3fe68b09758c

from __future__ import annotations
from enum import Enum
from mollie import utils


class AccountNumberFormatResponse(str, Enum, metaclass=utils.OpenEnumMeta):
    r"""The format of the account number."""

    IBAN = "iban"
