"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""
# @generated-id: 2c424d91d84f

from __future__ import annotations
from enum import Enum
from mollie import utils


class TransferSchemeTypeResponse(str, Enum, metaclass=utils.OpenEnumMeta):
    r"""The transfer scheme to be used for the transfer. The transfer scheme determines the processing time and method of the transfer."""

    SEPA_CREDIT_INST = "sepa-credit-inst"
    SEPA_CREDIT = "sepa-credit"
