"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""
# @generated-id: aeba1d370276

from __future__ import annotations
from .account_number_format import AccountNumberFormat
from mollie.types import BaseModel
import pydantic
from typing_extensions import Annotated, TypedDict


class CreditorBankAccountTypedDict(TypedDict):
    r"""The bank account details of the creditor (recipient) for Verification of Payee."""

    account_holder_name: str
    r"""The full name of the creditor account holder to verify against bank records."""
    format_: AccountNumberFormat
    r"""The format of the account number."""
    account_number: str
    r"""The bank account details of the creditor."""


class CreditorBankAccount(BaseModel):
    r"""The bank account details of the creditor (recipient) for Verification of Payee."""

    account_holder_name: Annotated[str, pydantic.Field(alias="accountHolderName")]
    r"""The full name of the creditor account holder to verify against bank records."""

    format_: Annotated[AccountNumberFormat, pydantic.Field(alias="format")]
    r"""The format of the account number."""

    account_number: Annotated[str, pydantic.Field(alias="accountNumber")]
    r"""The bank account details of the creditor."""


try:
    CreditorBankAccount.model_rebuild()
except NameError:
    pass
