"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""
# @generated-id: 250f4cb4d537

from __future__ import annotations
from enum import Enum
from mollie import utils


class SettlementPaymentStatus(str, Enum, metaclass=utils.OpenEnumMeta):
    r"""The payment's status. Settlement payments always have a status of `paid`."""

    PAID = "paid"
