"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""
# @generated-id: b8cfcc17d1ad

from __future__ import annotations
from enum import Enum
from mollie import utils


class StatusReasonCodeResponse(str, Enum, metaclass=utils.OpenEnumMeta):
    r"""A machine-readable code indicating the reason for the transfer's terminal status."""

    INSUFFICIENT_FUNDS = "insufficient-funds"
    REJECTED = "rejected"
    ERROR = "error"
