"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""
# @generated-id: 8971386eae33

from __future__ import annotations
from enum import Enum


class AccountNumberFormat(str, Enum):
    r"""The format of the account number."""

    IBAN = "iban"
