"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""
# @generated-id: f56d0df6ccff

from .basesdk import BaseSDK
from mollie import models, utils
from mollie._hooks import HookContext
from mollie.types import OptionalNullable, UNSET
from mollie.utils import get_security_from_env
from mollie.utils.unmarshal_json_response import unmarshal_json_response
from typing import Any, Mapping, Optional, Union


class VerifyPayees(BaseSDK):
    def create(
        self,
        *,
        idempotency_key: Optional[str] = None,
        verification_of_payee_request: Optional[
            Union[
                models.VerificationOfPayeeRequest,
                models.VerificationOfPayeeRequestTypedDict,
            ]
        ] = None,
        retries: OptionalNullable[utils.RetryConfig] = UNSET,
        server_url: Optional[str] = None,
        timeout_ms: Optional[int] = None,
        http_headers: Optional[Mapping[str, str]] = None,
    ) -> models.VerificationOfPayeeResponse:
        r"""Verify Payee

        > 🚧 Beta feature
        >
        > This feature is currently in beta testing, and the final specification may still change.

        Perform a Verification of Payee (VoP) check. This allows you to verify the account holder name against the
        records held by the receiving bank before initiating a transfer.

        The verification result indicates whether the provided name matches, closely matches, or does not match the
        name on file at the receiving bank. This helps prevent misdirected payments.

        ### Simulating verification scenarios in test mode

        In test mode, you can simulate various verification outcomes by adjusting the creditor name in the
        `creditorBankAccount.accountHolderName` property. This allows you to test all possible Verification of Payee
        results without needing special properties. The names are case insensitive.

        | Account holder name                    | Scenario                                      | Verification result | Suggested name |
        |----------------------------------------|-----------------------------------------------|---------------------|----------------|
        | `John Close Match`                     | Name closely matches the bank records          | `close-match`       | `John Match`   |
        | `John No Match`                        | Name does not match the bank records           | `no-match`          | —              |
        | `John Unavailable`                     | Verification is not available                  | `not-available`     | —              |
        | Any other name                         | Default: name matches the bank records         | `match`             | —              |

        If set, this operation will use `organization_access_token` from the global security.

        :param idempotency_key: A unique key to ensure idempotent requests. This key should be a UUID v4 string.
        :param verification_of_payee_request:
        :param retries: Override the default retry configuration for this method
        :param server_url: Override the default server URL for this method
        :param timeout_ms: Override the default request timeout configuration for this method in milliseconds
        :param http_headers: Additional headers to set or replace on requests.
        """
        base_url = None
        url_variables = None
        if timeout_ms is None:
            timeout_ms = self.sdk_configuration.timeout_ms

        if server_url is not None:
            base_url = server_url
        else:
            base_url = self._get_url(base_url, url_variables)

        request = models.VerifyPayeeRequest(
            idempotency_key=idempotency_key,
            verification_of_payee_request=utils.get_pydantic_model(
                verification_of_payee_request,
                Optional[models.VerificationOfPayeeRequest],
            ),
        )

        req = self._build_request(
            method="POST",
            path="/business-accounts/payee-verifications",
            base_url=base_url,
            url_variables=url_variables,
            request=request,
            request_body_required=False,
            request_has_path_params=False,
            request_has_query_params=True,
            user_agent_header="user-agent",
            accept_header_value="application/hal+json",
            http_headers=http_headers,
            security=self.sdk_configuration.security,
            get_serialized_body=lambda: utils.serialize_request_body(
                request.verification_of_payee_request if request is not None else None,
                False,
                True,
                "json",
                Optional[models.VerificationOfPayeeRequest],
            ),
            allow_empty_value=None,
            allowed_fields=["organization_access_token"],
            timeout_ms=timeout_ms,
        )

        if retries == UNSET:
            if self.sdk_configuration.retry_config is not UNSET:
                retries = self.sdk_configuration.retry_config
            else:
                retries = utils.RetryConfig(
                    "backoff", utils.BackoffStrategy(500, 5000, 2, 7500), True
                )

        retry_config = None
        if isinstance(retries, utils.RetryConfig):
            retry_config = (retries, ["5xx"])

        http_res = self.do_request(
            hook_ctx=HookContext(
                config=self.sdk_configuration,
                base_url=base_url or "",
                operation_id="verify-payee",
                oauth2_scopes=None,
                security_source=get_security_from_env(
                    self.sdk_configuration.security, models.Security
                ),
            ),
            request=req,
            error_status_codes=["422", "429", "4XX", "503", "5XX"],
            retry_config=retry_config,
        )

        response_data: Any = None
        if utils.match_response(http_res, "200", "application/hal+json"):
            return unmarshal_json_response(models.VerificationOfPayeeResponse, http_res)
        if utils.match_response(http_res, ["422", "429"], "application/hal+json"):
            response_data = unmarshal_json_response(models.ErrorResponseData, http_res)
            raise models.ErrorResponse(response_data, http_res)
        if utils.match_response(http_res, "503", "application/hal+json"):
            response_data = unmarshal_json_response(models.ErrorResponseData, http_res)
            raise models.ErrorResponse(response_data, http_res)
        if utils.match_response(http_res, "4XX", "*"):
            http_res_text = utils.stream_to_text(http_res)
            raise models.APIError("API error occurred", http_res, http_res_text)
        if utils.match_response(http_res, "5XX", "*"):
            http_res_text = utils.stream_to_text(http_res)
            raise models.APIError("API error occurred", http_res, http_res_text)

        raise models.APIError("Unexpected response received", http_res)

    async def create_async(
        self,
        *,
        idempotency_key: Optional[str] = None,
        verification_of_payee_request: Optional[
            Union[
                models.VerificationOfPayeeRequest,
                models.VerificationOfPayeeRequestTypedDict,
            ]
        ] = None,
        retries: OptionalNullable[utils.RetryConfig] = UNSET,
        server_url: Optional[str] = None,
        timeout_ms: Optional[int] = None,
        http_headers: Optional[Mapping[str, str]] = None,
    ) -> models.VerificationOfPayeeResponse:
        r"""Verify Payee

        > 🚧 Beta feature
        >
        > This feature is currently in beta testing, and the final specification may still change.

        Perform a Verification of Payee (VoP) check. This allows you to verify the account holder name against the
        records held by the receiving bank before initiating a transfer.

        The verification result indicates whether the provided name matches, closely matches, or does not match the
        name on file at the receiving bank. This helps prevent misdirected payments.

        ### Simulating verification scenarios in test mode

        In test mode, you can simulate various verification outcomes by adjusting the creditor name in the
        `creditorBankAccount.accountHolderName` property. This allows you to test all possible Verification of Payee
        results without needing special properties. The names are case insensitive.

        | Account holder name                    | Scenario                                      | Verification result | Suggested name |
        |----------------------------------------|-----------------------------------------------|---------------------|----------------|
        | `John Close Match`                     | Name closely matches the bank records          | `close-match`       | `John Match`   |
        | `John No Match`                        | Name does not match the bank records           | `no-match`          | —              |
        | `John Unavailable`                     | Verification is not available                  | `not-available`     | —              |
        | Any other name                         | Default: name matches the bank records         | `match`             | —              |

        If set, this operation will use `organization_access_token` from the global security.

        :param idempotency_key: A unique key to ensure idempotent requests. This key should be a UUID v4 string.
        :param verification_of_payee_request:
        :param retries: Override the default retry configuration for this method
        :param server_url: Override the default server URL for this method
        :param timeout_ms: Override the default request timeout configuration for this method in milliseconds
        :param http_headers: Additional headers to set or replace on requests.
        """
        base_url = None
        url_variables = None
        if timeout_ms is None:
            timeout_ms = self.sdk_configuration.timeout_ms

        if server_url is not None:
            base_url = server_url
        else:
            base_url = self._get_url(base_url, url_variables)

        request = models.VerifyPayeeRequest(
            idempotency_key=idempotency_key,
            verification_of_payee_request=utils.get_pydantic_model(
                verification_of_payee_request,
                Optional[models.VerificationOfPayeeRequest],
            ),
        )

        req = self._build_request_async(
            method="POST",
            path="/business-accounts/payee-verifications",
            base_url=base_url,
            url_variables=url_variables,
            request=request,
            request_body_required=False,
            request_has_path_params=False,
            request_has_query_params=True,
            user_agent_header="user-agent",
            accept_header_value="application/hal+json",
            http_headers=http_headers,
            security=self.sdk_configuration.security,
            get_serialized_body=lambda: utils.serialize_request_body(
                request.verification_of_payee_request if request is not None else None,
                False,
                True,
                "json",
                Optional[models.VerificationOfPayeeRequest],
            ),
            allow_empty_value=None,
            allowed_fields=["organization_access_token"],
            timeout_ms=timeout_ms,
        )

        if retries == UNSET:
            if self.sdk_configuration.retry_config is not UNSET:
                retries = self.sdk_configuration.retry_config
            else:
                retries = utils.RetryConfig(
                    "backoff", utils.BackoffStrategy(500, 5000, 2, 7500), True
                )

        retry_config = None
        if isinstance(retries, utils.RetryConfig):
            retry_config = (retries, ["5xx"])

        http_res = await self.do_request_async(
            hook_ctx=HookContext(
                config=self.sdk_configuration,
                base_url=base_url or "",
                operation_id="verify-payee",
                oauth2_scopes=None,
                security_source=get_security_from_env(
                    self.sdk_configuration.security, models.Security
                ),
            ),
            request=req,
            error_status_codes=["422", "429", "4XX", "503", "5XX"],
            retry_config=retry_config,
        )

        response_data: Any = None
        if utils.match_response(http_res, "200", "application/hal+json"):
            return unmarshal_json_response(models.VerificationOfPayeeResponse, http_res)
        if utils.match_response(http_res, ["422", "429"], "application/hal+json"):
            response_data = unmarshal_json_response(models.ErrorResponseData, http_res)
            raise models.ErrorResponse(response_data, http_res)
        if utils.match_response(http_res, "503", "application/hal+json"):
            response_data = unmarshal_json_response(models.ErrorResponseData, http_res)
            raise models.ErrorResponse(response_data, http_res)
        if utils.match_response(http_res, "4XX", "*"):
            http_res_text = await utils.stream_to_text_async(http_res)
            raise models.APIError("API error occurred", http_res, http_res_text)
        if utils.match_response(http_res, "5XX", "*"):
            http_res_text = await utils.stream_to_text_async(http_res)
            raise models.APIError("API error occurred", http_res, http_res_text)

        raise models.APIError("Unexpected response received", http_res)
