"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""
# @generated-id: 29e01828928a

from __future__ import annotations
from .transfer_scheme_type import TransferSchemeType
from mollie.types import BaseModel
from typing_extensions import TypedDict


class TransferSchemeTypedDict(TypedDict):
    r"""The scheme, as requested by the client."""

    type: TransferSchemeType
    r"""The transfer scheme to be used for the transfer. The transfer scheme determines the processing time and method of the transfer."""


class TransferScheme(BaseModel):
    r"""The scheme, as requested by the client."""

    type: TransferSchemeType
    r"""The transfer scheme to be used for the transfer. The transfer scheme determines the processing time and method of the transfer."""
