"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""
# @generated-id: 7679aeb6b4f9

from __future__ import annotations
from enum import Enum
from mollie import utils


class SettlementRefundStatus(str, Enum, metaclass=utils.OpenEnumMeta):
    r"""The refund's status. Settlement refunds always have a status of `refunded`."""

    REFUNDED = "refunded"
