"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""
# @generated-id: ab7f5a0e11d2

from __future__ import annotations
from enum import Enum
from mollie import utils


class SettlementCaptureStatus(str, Enum, metaclass=utils.OpenEnumMeta):
    r"""The capture's status. Settlement captures always have a status of `succeeded`."""

    SUCCEEDED = "succeeded"
