"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""
# @generated-id: 5cd8e3d5cfbf

from __future__ import annotations
from enum import Enum
from mollie import utils


class CreditDebitIndicator(str, Enum, metaclass=utils.OpenEnumMeta):
    r"""Indicates whether the transfer is a credit or debit transaction from the perspective of the account holder."""

    CREDIT = "credit"
    DEBIT = "debit"
