"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""
# @generated-id: b405ad468147

from __future__ import annotations
from enum import Enum
from mollie import utils


class TransferStatus(str, Enum, metaclass=utils.OpenEnumMeta):
    r"""The status of the transfer."""

    REQUESTED = "requested"
    INITIATED = "initiated"
    PENDING_REVIEW = "pending-review"
    PROCESSED = "processed"
    FAILED = "failed"
    BLOCKED = "blocked"
    INCOMING_SETTLED = "incoming-settled"
